changeset 8015:3d6ee294a710

Fix bits of last change lost in Emacs crash.
author Roland McGrath <roland@gnu.org>
date Thu, 23 Jun 1994 01:30:12 +0000
parents 0d4288705550
children 51c69c76c3cc
files lisp/progmodes/etags.el
diffstat 1 files changed, 5 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/progmodes/etags.el	Thu Jun 23 01:11:38 1994 +0000
+++ b/lisp/progmodes/etags.el	Thu Jun 23 01:30:12 1994 +0000
@@ -369,9 +369,11 @@
 		;; the one which includes the table we found.
 		(setq could-be (cons (car elt) could-be)))
 	    (setq elt (cdr elt)))
-	  ;; The last element we found in the computed list before
-	  ;; FOUND that appears in the 
-    found))
+	  ;; The last element we found in the computed list before FOUND
+	  ;; that appears in the user's list will be the table that
+	  ;; included the one we found.  This will be the head of the
+	  ;; COULD-BE list.
+	  (car could-be)))))
 
 ;; Subroutine of visit-tags-table-buffer.  Move tags-table-list-pointer
 ;; along and set tags-file-name.  Returns nil when out of tables.